@@ -180,7 +180,8 @@ try:
     if args.post_cmd:
         exec(args.post_cmd)
 except Exception as ex:
-    print(ex)
+    import traceback
+    print(traceback.format_exc())
 
 def main():
     pass
